package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.Training;

/**
 * 考核培训Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface TrainingMapper 
{
    /**
     * 查询考核培训
     * 
     * @param trainingId 考核培训主键
     * @return 考核培训
     */
    public Training selectTrainingByTrainingId(Long trainingId);

    /**
     * 查询考核培训列表
     * 
     * @param training 考核培训
     * @return 考核培训集合
     */
    public List<Training> selectTrainingList(Training training);

    /**
     * 新增考核培训
     * 
     * @param training 考核培训
     * @return 结果
     */
    public int insertTraining(Training training);

    /**
     * 修改考核培训
     * 
     * @param training 考核培训
     * @return 结果
     */
    public int updateTraining(Training training);

    /**
     * 删除考核培训
     * 
     * @param trainingId 考核培训主键
     * @return 结果
     */
    public int deleteTrainingByTrainingId(Long trainingId);

    /**
     * 批量删除考核培训
     * 
     * @param trainingIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTrainingByTrainingIds(Long[] trainingIds);

    /**
     * 查询考核培训列表
     *
     * @return 考核培训集合
     */
    public List<Training> getTrainingList();
}
